summaryrefslogtreecommitdiff
path: root/src/strings/tstring.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/strings/tstring.hpp')
-rw-r--r--src/strings/tstring.hpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/strings/tstring.hpp b/src/strings/tstring.hpp
index 49ec4ab..700ec3d 100644
--- a/src/strings/tstring.hpp
+++ b/src/strings/tstring.hpp
@@ -20,20 +20,21 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
# include "base.hpp"
-# include "fstring.hpp"
+# include "rstring.hpp"
namespace strings
{
/// An owning string that represents a tail slice of an FString.
/// Guaranteed to be NUL-terminated.
class TString : public _crtp_string<TString, TString, ZPair>
{
friend class SString;
- FString _s;
+ RString _s;
size_t _o;
public:
TString();
- TString(FString b, size_t i=0);
+ TString(RString b, size_t i=0);
+ TString(AString b, size_t i=0);
//TString(const TString&)
TString(const SString&);
TString(const ZString&);
@@ -50,7 +51,7 @@ namespace strings
iterator begin() const;
iterator end() const;
- const FString *base() const;
+ const RString *base() const;
const char *c_str() const;
};
@@ -20,20 +20,21 @@
namespace strings
{
- /// An owning string that represents a tail slice of an FString.
+ /// An owning string that represents a tail slice of an RString.
/// Guaranteed to be NUL-terminated.
class TString : public _crtp_string<TString, TString, ZPair>